==> gregtech_flow-0.4.2.tar.gz: gregtech_flow-0.4.2/README.md <==
<p></p>
<p align="center"><img src="https://raw.githubusercontent.com/velolib/gregtech-flow/master/assets/gt_flow.png"/></p>
<br>
<p align="center">
    <a href="https://pypi.org/project/gregtech-flow/">
        <img alt="PyPI - Python Version" src="https://img.shields.io/pypi/pyversions/gregtech.flow?style=for-the-badge">
    </a>
    <a href="https://pypi.org/project/gregtech-flow/" >
        <img alt="PyPI" src="https://img.shields.io/pypi/v/gregtech-flow?style=for-the-badge">
    </a>
    <a href="https://github.com/velolib/gregtech-flow/blob/master/LICENSE.txt" >
        <img src="https://img.shields.io/github/license/velolib/gregtech-flow?style=for-the-badge" alt="License MIT"/>
    </a>
    <a href="https://codecov.io/github/velolib/gregtech-flow" >
        <img src="https://img.shields.io/codecov/c/github/velolib/gregtech-flow?style=for-the-badge&token=Y59FTD1UC1" alt="Code Coverage"/>
    </a>
</p>
<p></p>

## ❓ What is it?
<img align="right" width="192" height="192" src="https://raw.githubusercontent.com/velolib/gregtech-flow/master/assets/logo_512x.png"/>

This is a fork of OrderedSet86's [gtnh-flow](https://github.com/OrderedSet86/gtnh-flow). In addition to the functionalities of the original tool, this fork has:
1. Extended formatting of projects
2. Added stylization add formatting of graphs
3. Standards to increase readability
4. A custom command line interface

To view the full documentation see the official [GT: Flow website](https://velolib.github.io/gregtech-flow/).

## 📖 Samples
Samples of the graphs included in the repository.
<details open>
    <summary><strong>Samples</strong></summary>
    <img src="https://raw.githubusercontent.com/velolib/gregtech-flow/c5f8a9e02e2a1f2f84ab92f0ce28d2a6c3e620cc/samples/rutile-titanium.svg" alt="Rutile -> Titanium">
    <img src="https://raw.githubusercontent.com/velolib/gregtech-flow/c5f8a9e02e2a1f2f84ab92f0ce28d2a6c3e620cc/samples/epoxid.svg" alt="Epoxid">
</details>

==> gregtech_flow-0.4.4.tar.gz: gregtech_flow-0.4.4/README.md <==
<p></p>
<p align="center"><img src="https://raw.githubusercontent.com/velolib/gregtech-flow/master/assets/gt_flow.png"/></p>
<br>
<p align="center">
    <a href="https://pypi.org/project/gregtech-flow/">
        <img alt="PyPI - Python Version" src="https://img.shields.io/pypi/pyversions/gregtech.flow?style=for-the-badge">
    </a>
    <a href="https://pypi.org/project/gregtech-flow/" >
        <img alt="PyPI" src="https://img.shields.io/pypi/v/gregtech-flow?style=for-the-badge">
    </a>
    <a href="https://github.com/velolib/gregtech-flow/blob/master/LICENSE.txt" >
        <img src="https://img.shields.io/github/license/velolib/gregtech-flow?style=for-the-badge" alt="License MIT"/>
    </a>
    <a href="https://codecov.io/github/velolib/gregtech-flow" >
        <img src="https://img.shields.io/codecov/c/github/velolib/gregtech-flow?style=for-the-badge&token=Y59FTD1UC1" alt="Code Coverage"/>
    </a>
    <a href="https://velolib.github.io/gregtech-flow/">
        <img alt="GitHub deployments" src="https://img.shields.io/github/deployments/velolib/gregtech-flow/github-pages?label=deployment&style=for-the-badge">
    </a>
</p>
<p></p>

## ❓ What is it?
<img align="right" width="192" height="192" src="https://raw.githubusercontent.com/velolib/gregtech-flow/master/assets/logo_512x.png"/>

This is a fork of OrderedSet86's [gtnh-flow](https://github.com/OrderedSet86/gtnh-flow). In addition to the functionalities of the original tool, this fork has:
1. Extended formatting of projects
2. Added stylization add formatting of graphs
3. Standards to increase readability
4. A custom command line interface
5. Full documentation

To view the full documentation see the official [GT: Flow website](https://velolib.github.io/gregtech-flow/).

## 📖 Samples
Samples of the graphs included in the repository.
<details open>
    <summary><strong>Samples</strong></summary>
    <img src="https://raw.githubusercontent.com/velolib/gregtech-flow/c5f8a9e02e2a1f2f84ab92f0ce28d2a6c3e620cc/samples/rutile-titanium.svg" alt="Rutile -> Titanium">
    <img src="https://raw.githubusercontent.com/velolib/gregtech-flow/c5f8a9e02e2a1f2f84ab92f0ce28d2a6c3e620cc/samples/epoxid.svg" alt="Epoxid">
</details>
